@@ -61,10 +61,14 @@ class transfer_learner():
             if 'X_train' in dic and 'X_val' in dic and 'y_train' in dic and 'y_val' in dic:
                 
                 self.X_train = dic['X_train']
-                self.X_val = dic['X_val']
+                self.X_val = dic['X_val']                
                 self.y_train = dic['y_train']
                 self.y_val = dic['y_val']
 
+                if 'X_test' in dic and 'y_test' in dic: # ldad optional test set
+                    self.X_test = dic['X_test']
+                    self.y_test = dic['y_test']
+
             elif 'X' in dic and 'y' in dic:
 
                 X = dic['X']
@@ -390,7 +394,7 @@ class transfer_learner():
             x = restore_image(X[i])
             ax.imshow(x)
             # ax.imshow((X_val[i] - X_val[i].min())/(X_val[i].max()-X_val[i].min()))
-            title = 'Predict: {}\n {} \n Actual: {}'.format(self.class_names[int(p.argmax(-1))], 
+            title = '\nPredict: {}\n {} \n Actual: {}'.format(self.class_names[int(p.argmax(-1))], 
             np.round(p[0],2), self.class_names[int(y[i].argmax(-1))])
             ax.set_title(title)
 
